@@ -97,11 +97,16 @@ async def exec_access_with_total(inc: InputContext,
                                  model: Type[AbstractDbModel],
                                  container: GenericDependencyContainer = None,
                                  fetch_fields: List[str] = None,
+                                 drop_cols: List[str] = None,
+                                 full_info: bool = False,
                                  middleware: Type[ModelLoader] = ModelLoader,
                                  external_callback: AccessCallback = None,
                                  retrieved_callback: AccessCallback = None):
     """Return from read_all dict with "items" and "total" """
-    result = await exec_access(inc=inc, model=model, container=container, fetch_fields=fetch_fields,
+    result = await exec_access(inc=inc, model=model, container=container,
+                               fetch_fields=fetch_fields,
+                               drop_cols=drop_cols,
+                               full_info=full_info,
                                middleware=middleware,
                                external_callback=external_callback,
                                retrieved_callback=retrieved_callback)
