@@ -1,19 +1,20 @@
 from typing import Any
 
-from web_foundation.config import GenericConfig
+from web_foundation.config import AppConf
 from web_foundation.kernel.messaging.channel import IChannel
+from web_foundation.kernel.stage import ListenerRegistrator
 
 
 class Resource:
     _communicator: Any | None
     _channel: IChannel | None
     _inited: bool
-    _config: GenericConfig
+    _config: AppConf
 
     def __init__(self, *args, **kwargs):
         _inited = False
 
-    async def init(self, config: GenericConfig, channel: IChannel | None = None, communicator: Any | None = None, *args,
+    async def init(self, config: AppConf, channel: IChannel | None = None, communicator: Any | None = None, *args,
                    **kwargs) -> None:
         self._config = config
         self._channel = channel
@@ -23,7 +24,12 @@ class Resource:
     async def shutdown(self):
         raise NotImplementedError
 
-    async def before_app_run(self, config: GenericConfig, *args, **kwargs):
+    def clear(self):
+        self._inited = False
+        self._communicator = None
+        self._channel = None
+
+    def set_listeners(self, registrator: ListenerRegistrator):
         pass
 
     @property
